@@ -40,7 +40,7 @@ static void      atk_component_real_get_size                 (AtkComponent *comp
                                                               gint         *height);
 
 GType
-atk_component_get_type ()
+atk_component_get_type (void)
 {
   static GType type = 0;
 
@@ -302,7 +302,6 @@ atk_component_get_size       (AtkComponent    *component,
   else
     real_height = &local_height;
 
-  iface = ATK_COMPONENT_GET_IFACE (component);
   g_return_if_fail (ATK_IS_COMPONENT (component));
 
   iface = ATK_COMPONENT_GET_IFACE (component);
@@ -318,6 +317,53 @@ atk_component_get_size       (AtkComponent    *component,
   }
 }
 
+/**
+ * atk_component_get_layer:
+ * @accessible: an #AtkComponent
+ *
+ * Gets the layer of the accessible.
+ *
+ * Returns: an #AtkLayer which is the layer of the accessible
+ **/
+AtkLayer
+atk_component_get_layer (AtkComponent *accessible) 
+{
+  AtkComponentIface *iface;
+
+  g_return_val_if_fail (ATK_IS_COMPONENT (accessible), ATK_LAYER_INVALID);
+
+  iface = ATK_COMPONENT_GET_IFACE (accessible);
+  if (iface->get_layer)
+    return (iface->get_layer) (accessible);
+  else
+    return ATK_LAYER_WIDGET;
+}
+
+/**
+ * atk_component_get_mdi_zorder:
+ * @accessible: an #AtkComponent
+ *
+ * Gets the zorder of the accessible. The value G_MININT will be returned 
+ * if the layer of the accessible is not ATK_LAYER_MDI.
+ *
+ * Returns: a gint which is the zorder of the accessible, i.e. the depth at 
+ * which the component is shown in relation to other components in the same 
+ * container.
+ **/
+gint
+atk_component_get_mdi_zorder (AtkComponent *accessible) 
+{
+  AtkComponentIface *iface;
+
+  g_return_val_if_fail (ATK_IS_COMPONENT (accessible), G_MININT);
+
+  iface = ATK_COMPONENT_GET_IFACE (accessible);
+  if (iface->get_mdi_zorder)
+    return (iface->get_mdi_zorder) (accessible);
+  else
+    return G_MININT;
+}
+
 /**
  * atk_component_grab_focus:
  * @component: an #AtkComponent
@@ -506,3 +552,6 @@ atk_component_real_get_size (AtkComponent *component,
 
   atk_component_get_extents (component, &x, &y, width, height, coord_type);
 }
+
+
+
